@@ -53,9 +53,7 @@ impl Time {
     }
 
     pub fn is_expired(&self) -> bool {
-        self.created_at
-            .elapsed()
-            .map_or(false, |d| if d >= self.d { true } else { false })
+        self.created_at.elapsed().map_or(false, |d| d >= self.d)
     }
 
     pub fn get_ttl(&self) -> Duration {
@@ -72,19 +70,11 @@ impl Time {
 }
 
 /// Bucket is a map of key to conflict.
-#[derive(Debug)]
+#[derive(Debug, Default)]
 struct Bucket<S = RandomState> {
     map: HashMap<u64, u64, S>,
 }
 
-impl Default for Bucket {
-    fn default() -> Self {
-        Self {
-            map: HashMap::new(),
-        }
-    }
-}
-
 impl<S: BuildHasher> Bucket<S> {
     pub fn with_hasher(hasher: S) -> Self {
         Self {
@@ -204,6 +194,10 @@ impl<S: BuildHasher + Clone + 'static> ExpirationMap<S> {
             .remove(&bucket_num)
             .map(|bucket| bucket.map)
     }
+
+    pub fn hasher(&self) -> S {
+        self.hasher.clone()
+    }
 }
 
 unsafe impl<S: BuildHasher + Clone + 'static> Send for ExpirationMap<S> {}
